import { IDestroyable } from 'destroyable';
import { BehaviorSubject } from 'rxjs';
import { IObservableStorage } from '../../interfaces/IObservableStorage';
import { ISerializable } from '../../interfaces/ISerializable';
import { ISerialized } from '../../interfaces/ISerialized';
import { IStorage } from '../../interfaces/IStorage';
import { Serializer } from '../../utils/Serializer';
import { IBrowserHistoryStorageOptions } from './IBrowserHistoryStorageOptions';
export declare abstract class AbstractBrowserHistoryStorage<TValue extends ISerializable> implements IObservableStorage<TValue>, IDestroyable {
    readonly defaultValue: TValue;
    private baseStorage?;
    protected serializer: Serializer<TValue>;
    isDestroyed: boolean;
    values: BehaviorSubject<TValue>;
    private valuesToSave;
    private options;
    private uniqueIdentifier;
    private storage?;
    private initialized;
    /**
     * This is saved to be able to destoroy
     */
    private popstateEventListener;
    constructor(defaultValue: TValue, options?: Partial<IBrowserHistoryStorageOptions>, baseStorage?: IStorage<ISerialized> | undefined, serializer?: Serializer<TValue>);
    get value(): TValue;
    set value(value: TValue);
    setValue(partialValue: Partial<TValue>): void;
    destroy(): void;
    createLink(value: Partial<TValue>, baseUrl?: URL | string): URL;
    initialize(): Promise<void>;
    protected abstract decodeUrl(url: URL): Partial<TValue>;
    protected abstract encodeUrl(params: TValue, lastUrl: URL): URL;
    protected createUniqueIdentifier(): string;
}
