import { Promisable } from 'type-fest';
import { ISerializable } from '../interfaces/ISerializable';
import { ISerialized } from '../interfaces/ISerialized';
import { IStorage } from '../interfaces/IStorage';
import { Serializer } from '../utils/Serializer';
/**
 * This class behaves like LocalStorage but entries are objects
 * TODO: This is taken from CollBoard and should be reviewed
 */
export declare class SerializedStorage<T extends ISerializable> {
    private baseStorage;
    private serializer;
    constructor(baseStorage: IStorage<ISerialized>, serializer: Serializer<T>);
    /**
     * Returns the number of key/value pairs currently present in the list associated with the object.
     */
    get length(): Promisable<number>;
    /**
     * Empties the list associated with the object of all key/value pairs, if there are any.
     */
    clear(): void;
    /**
     * Returns the current value associated with the given key, or null if the given key does not exist in the list associated with the object.
     */
    getItem(key: string): Promise<T | null>;
    /**
     * Returns the name of the nth key in the list, or null if n is greater than or equal to the number of key/value pairs in the object.
     */
    key(index: number): string | null;
    /**
     * Removes the key/value pair with the given key from the list associated with the object, if a key/value pair with the given key exists.
     */
    removeItem(key: string): void;
    /**
     * Sets the value of the pair identified by key to value, creating a new key/value pair if none existed for key previously.
     */
    setItem(key: string, value: T): Promisable<void>;
}
